## Server Requests

Here are the current logged requests in this server

<script type="module" src="/web_components/js/elements/ui/WebC__Server_Requests.mjs"></script>

<webc-server-requests api_path="/api/server/requests/requests-data?return_type=table"  ></webc-server-requests>



